import React, { useState, useEffect } from 'react'

import Head from 'next/head'
import Link from 'next/link'

import constants from '../constants.json'
import ExternalLinkIcon from '../components/externalLinkIcon'

import styles from './script.module.css'

function fetchSupportedSites(from) {
  return new Promise((resolve) => {
    fetch(`${constants.apiUrl}supportedSites`, {
      credentials: 'include',
    })
      .then((resp) => {
        return resp.json()
      })
      .then((res) => {
        resolve(res)
      })
  })
}

export default function Script() {
  const [supportedSites, setSupportedSites] = useState()

  useEffect(() => {
    fetchSupportedSites().then((res) => {
      setSupportedSites(res)
    })
  }, [])

  return (
    <div className={styles.content}>
      <Head>
        <title>Script - Qmining | Frylabs.net</title>
      </Head>
      <div className={'pageHeader'}>
        <h1>Script</h1>
      </div>
      <div className={'buttonContainer'}>
        <a
          href="https://www.tampermonkey.net/"
          target="_blank"
          rel="noreferrer"
        >
          Ajánlott userscript kezelő bővítmény
          <ExternalLinkIcon size={15} />
        </a>
        <a href="/install">
          Script telepítése
          <ExternalLinkIcon size={15} />
        </a>
      </div>
      <center>
        <h2 className={'subtitle'}>A userscript telepítése, és használata</h2>
      </center>
      <div>
        <p>
          Ez a userscript Moodle/Elearnig/KMOOC tesztek megoldása során
          segítséget jelenít meg.
        </p>
        {supportedSites && (
          <>
            <b>Script jelenleg a következő oldalakon működik:</b>
            <ul>
              {supportedSites.map((ss) => {
                return <li key={ss}>{ss}</li>
              })}
            </ul>
          </>
        )}
        <b>Telepítés lépései:</b>
        <ol>
          <li>
            Tölts le egy userscript futtató kiegészítőt a böngésződhöz: pl. a{' '}
            <a
              href="https://www.tampermonkey.net/"
              target="_blank"
              rel="noreferrer"
            >
              Tampermonkey
            </a>
            -t
          </li>
          <li>
            <a
              href="http://qmining.frylabs.net/install"
              target="_blank"
              rel="noreferrer"
            >
              Kattints ide hogy felrakd a scriptet
            </a>{' '}
          </li>
          <li>
            Ha megnyitod az egyik támogatott oldalon a scriptet, akkor
            használata előtt engedélyezned kell, hogy a szerverrel kommunikáljon
            a script
          </li>
          <li>
            Ezután a script egy apró menü ablakot jelenít meg a weboldal bal
            alsó részén
          </li>
          <li>
            Ha be vagy jelentkezve, akkor a teszt oldalakon a megoldásokat
            kellene látnod egy felugró ablakban felül. Ha nem, akkor{' '}
            <Link href="/faq">
              <a>GYIK</a>
            </Link>
            -be olvass bele, vagy{' '}
            <Link href="/contact">
              <a>írj üzenetet mi nem működik</a>
            </Link>
          </li>
        </ol>
        <b>Script működési elve:</b>
        <ul>
          <li>
            Az egész folyamat a teszt ellenőrzés oldalon kezdődik, a script
            onnan beolvassa, és szervernek beküldi a helyes válaszokat
          </li>
          <li>
            Ezután ha újból kitöltöd a tesztet, vagy ugyanazzal a kérdéssel
            találkozol másik tesztben (pl.: zh/vizsga) akkor ott megjeleníti a
            választ
          </li>
          <li>
            Más felhasználóknak köszönhetően már valószínűleg lesznek megoldások
            a tesztjeidhez.{' '}
            <Link href="/allQuestions">
              <a>Itt</a>
            </Link>{' '}
            meg tudod tekinteni, hogy vannak-e válaszok a tárgyadhoz.
          </li>
          <li>
            Ha teszt ellenőrzés oldal nem elérhető, vagy nem egyértelműen
            kitalálható a helyes válasz, akkor a script nem tud mit csinálni,
            nem ment le semmit
          </li>
        </ul>
        <b>Egyéb fontos tudnivalók:</b>
        <ul>
          <li>
            <Link href="/allQuestions">
              <a>Itt elérhető online az összes kérdés</a>
            </Link>{' '}
            ha esetleg a script valamiért nem működne.
          </li>
          <li>
            <a
              href="http://qmining.frylabs.net/allqr.txt"
              target="_blank"
              rel="noreferrer"
            >
              Itt megtalálható az összes kérdés letölthető TXT változatban
            </a>{' '}
            ha esetleg nem lenne elérhető a szerver, vagy bármi hiba történne
          </li>
        </ul>
      </div>
    </div>
  )
}
